package com.casic.missiles.modular.system.service;

import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.casic.missiles.core.datascope.DataScope;

import java.util.Map;

public interface DeviceTubeService {

    /**
     * 获取点位信息
     *
     * @return
     */
    Object deviceList(DataScope dataScope);

    /**
     * 获取设备列表信息
     *
     * @param dataScope
     * @return
     */
    Object deviceGroupsList(DataScope dataScope);


    /**
     * 获取设备列表信息
     *
     * @param wellGroupId
     * @return
     */
    Object groupDeviceListPage(Integer oreder, Page<Map<String, Object>> page, String wellGroupId, DataScope dataScope);

    Object tubeDataHistory(Page<Map<String, Object>> page, String DEVCOE, String beginTime, String endTime);


    /**
     * 获取同一个组设备列表信息
     *
     * @param wellGroupId
     * @return
     */
    Object groupDeviceList(String wellGroupId, DataScope dataScope);

    /**
     * 获取详情信息
     */
    Object deviceDetail(String id);;

}
