package com.casic.missiles.modular.system.dao;

import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.casic.missiles.core.datascope.DataScope;
import org.apache.ibatis.annotations.Mapper;
import org.apache.ibatis.annotations.Param;

import java.util.List;
import java.util.Map;

@Mapper
public interface DeviceTubeMapper {

    List<Map<String, Object>> deviceList(@Param("scope") DataScope dataScope);

    List<Map<String, Object>> deviceGroupsList(@Param("scope") DataScope dataScope);

    List<Map<String, Object>> groupDeviceListPage(@Param("page") Page<Map<String, Object>> page, @Param("wellGroupId") String wellGroupId,
                                                  @Param("scope") DataScope dataScope);

    Map<String, Object> dataTubeByDevcode(@Param("devcode") String devcode);

    List<Map<String, Object>> tubeDataHistory(@Param("page") Page<Map<String, Object>> page, @Param("devcode") String devcode,
                                              @Param("endTime") String endTime, @Param("beginTime") String beginTime);


    List<Map<String, Object>> groupDeviceList(@Param("wellGroupId") String wellGroupId, @Param("scope") DataScope dataScope);

    Map<String, Object> deviceDetail(@Param("id") Long id);

}
